/*
 * Name:    smv_bias.c
 *
 * Purpose: Creates an SMV format file where the pixels for each sector
 *          has the same value as for the corresponding sector of a
 *          supplied SMV image file.
 *
 * Author:  William Lavender
 *
 *------------------------------------------------------------------------
 *
 * Copyright 2007, 2012 Illinois Institute of Technology
 *
 * See the file "LICENSE" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 */

#define SMV_BIAS_DEBUG	TRUE

#include <stdio.h>
#include <stdlib.h>
#include <math.h>

#include "mx_util.h"
#include "mx_stdint.h"
#include "mx_array.h"
#include "mx_image.h"

int
main( int argc, char *argv[] )
{
	MX_IMAGE_FRAME *source_frame, *destination_frame;
	long row_binsize, column_binsize;
	char *source_filename, *destination_filename;
	mx_status_type mx_status;

	if ( argc != 5 ) {
		fprintf(stderr, "Usage: smv_rebin row_binsize "
				"column_binsize source_file dest_file\n" );
		exit(1);
	}

	row_binsize = atol( argv[1] );
	column_binsize = atol( argv[2] );
	source_filename = argv[3];
	destination_filename = argv[4];

	/* Load the initial SMV file. */

	source_frame = calloc( 1, sizeof(MX_IMAGE_FRAME) );

	if ( source_frame == NULL ) {
		fprintf( stderr,
		"Could not allocate memory for a source_frame structure.\n");
		exit(1);
	}

	fprintf( stderr, "Reading source file '%s' ... ", source_filename );

	mx_status = mx_image_read_smv_file( &source_frame,
					MXT_IMAGE_FILE_SMV,
					source_filename );

	if ( mx_status.code != MXE_SUCCESS )
		exit(1);

	fprintf( stderr, "Succeeded.\n" );

	fprintf( stderr, "Rebinning source image ... " );

	destination_frame = calloc( 1, sizeof(MX_IMAGE_FRAME) );

	if ( destination_frame == NULL ) {
		fprintf( stderr,
	    "Could not allocate memory for a destination_frame structure.\n");
		exit(1);
	}

	mx_status = mx_image_rebin( &destination_frame, source_frame,
					row_binsize, column_binsize );

	if ( mx_status.code != MXE_SUCCESS )
		exit(1);

	fprintf( stderr, "Succeeded.\n" );

	fprintf( stderr, "Writing destination file '%s' ... ",
						destination_filename );

	mx_status = mx_image_write_smv_file( destination_frame,
						MXT_IMAGE_FILE_SMV,
						destination_filename );

	if ( mx_status.code != MXE_SUCCESS )
		exit(1);

	fprintf( stderr, "Succeeded.\n" );

	exit(0);
}

